.. _models:

Models
******

.. currentmodule:: torchkge.models


Translational Models
====================

.. automodule:: torchkge.models.TranslationModels

.. autoclass:: torchkge.models.TranslationModels.TransEModel
   :members:
.. autoclass:: torchkge.models.TranslationModels.TransHModel
   :members:
.. autoclass:: torchkge.models.TranslationModels.TransRModel
   :members:
.. autoclass:: torchkge.models.TranslationModels.TransDModel
   :members:

